@@ -24,6 +24,8 @@ class cryfs : public engines::engine
 public:
 	cryfs() ;
 
+	const QProcessEnvironment& getProcessEnvironment() const override ;
+
 	engines::engine::status errorCode( const QString& e,int s ) const override ;
 
 	engines::engine::args command( const QString& password,
@@ -33,5 +35,6 @@ public:
 
 	void GUICreateOptionsinstance( QWidget * parent,engines::engine::function ) const override ;
 private:
+	QProcessEnvironment m_env ;
 	mutable QString m_version ;
 } ;
