@@ -23,6 +23,15 @@ struct ecryptfs : public engines::engine
 {
 	ecryptfs() ;
 
+	bool requiresPolkit() const override ;
+
+	void updateMountOptions( engines::engine::options&,
+				 QString& configFilePath ) const override ;
+
+	bool unmount( const QString& cipherFolder,
+		      const QString& mountPoint,
+		      int maxCount ) const override ;
+
 	engines::engine::status errorCode( const QString& e,int s ) const override ;
 
 	engines::engine::args command( const QString& password,
@@ -31,4 +40,8 @@ struct ecryptfs : public engines::engine
 	QString installedVersionString() const override ;
 
 	void GUICreateOptionsinstance( QWidget * parent,engines::engine::function ) const override ;
+
+private:
+	mutable bool m_unset = true ;
+	mutable bool m_requirePolkit = true ;
 } ;
