@@ -24,6 +24,10 @@ class sshfs : public engines::engine
 public:
 	sshfs() ;
 
+	engine::engine::status passMinimumVersion() const ;
+
+	const QProcessEnvironment& getProcessEnvironment() const override ;
+
 	engines::engine::status errorCode( const QString& e,int s ) const override ;
 
 	engines::engine::args command( const QString& password,
@@ -34,4 +38,5 @@ public:
 	void GUICreateOptionsinstance( QWidget * parent,engines::engine::function ) const override ;
 private:
 	mutable QString m_version ;
+	mutable QProcessEnvironment m_environment ;
 } ;
