@@ -1,4 +1,4 @@
-﻿/*
+/*
  *
  *  Copyright (c) 2012-2015
  *  name : Francis Banyikwa
@@ -501,17 +501,17 @@ static void _connect_to_ssh_server( QWidget * parent,const favorites::entry& ent
 {
 	auto s = siritask::encryptedFolderMount( entry ) ;
 
-	if( s == engines::engine::status::sshfsNotFound ){
+	if( s.cmdStatus() == engines::engine::status::sshfsNotFound ){
 
 		auto e = QObject::tr( "Failed To Complete The Request.\nSshfs Executable Could Not Be Found." ) ;
 
 		DialogMsg( parent ).ShowUIOK( QObject::tr( "ERROR" ),e ) ;
 
-	}else if( s != engines::engine::status::success ){
+	}else if( s.cmdStatus() != engines::engine::status::success ){
 
 		auto e = QObject::tr( "Failed To Connect To \"%1\" And Below Log was Generated By The Backend.\n" ).arg( entry.volumePath ) ;
 
-		e += "\n----------------------------------------\n" + s.toMiniString() ;
+		e += "\n----------------------------------------\n" + s.cmdStatus().toMiniString() ;
 
 		DialogMsg( parent ).ShowUIOK( QObject::tr( "ERROR" ),e ) ;
 	}
@@ -553,7 +553,7 @@ void sirikali::favoriteClicked( QAction * ac )
 
 				if( _found( it ) ){
 
-					auto s = siritask::mountEngine( it.first.volumePath,QString() ).engine.name() ;
+					auto s = siritask::mountEngine( it.first.volumePath,QString() ).engine().name() ;
 
 					if( it.first.volumeNeedNoPassword && s == "sshfs" ){
 
@@ -735,7 +735,7 @@ void sirikali::cliCommand( const QStringList& l )
 
 			if( a == volume || b == volume ){
 
-				if( siritask::encryptedFolderUnMount( a,b,c ) ){
+				if( siritask::encryptedFolderUnMount( a,b,c,5 ).success() ){
 
 					siritask::deleteMountFolder( b ) ;
 
@@ -802,7 +802,7 @@ void sirikali::unlockVolume( const QStringList& l )
 
 			auto e = siritask::encryptedFolderMount( s ) ;
 
-			if( e == engines::engine::status::success ){
+			if( e.cmdStatus() == engines::engine::status::success ){
 
 				//this->openMountPointPath( m ) ;
 
@@ -818,7 +818,7 @@ void sirikali::unlockVolume( const QStringList& l )
 
 				auto e = utility::readPassword() ;
 
-				if( keyFile.isEmpty() ){ ;
+				if( keyFile.isEmpty() ){
 
 					return e ;
 				}else{
@@ -904,7 +904,8 @@ void sirikali::mountMultipleVolumes( favorites::volumeList e )
 				     m_autoOpenFolderOnMount,
 				     m_folderOpener,
 				     std::move( e ),
-				     [ this ](){ m_disableEnableAll = false ; this->enableAll() ; } ) ;
+				     [ this ](){ m_disableEnableAll = false ; this->enableAll() ; },
+				     [ this ](){ this->updateList() ; } ) ;
 	}
 }
 
@@ -991,9 +992,17 @@ favorites::volumeList sirikali::autoUnlockVolumes( favorites::volumeList l,bool
 			}else{
 				auto s = siritask::encryptedFolderMount( { e.first,key } ) ;
 
-				if( s == engines::engine::status::success && autoOpenFolderOnMount ){
+				if( s.cmdStatus() == engines::engine::status::success ){
 
-					this->openMountPointPath( e.first.mountPointPath ) ;
+					if( autoOpenFolderOnMount ){
+
+						this->openMountPointPath( e.first.mountPointPath ) ;
+					}
+
+					if( s.backendDoesNotAutoRefresh() ){
+
+						this->updateList() ;
+					}
 				}
 			}
 		} ;
@@ -1050,33 +1059,14 @@ void sirikali::volumeProperties()
 
 	const auto& engine = engines::instance().getByName( volumeType ) ;
 
-	for( const auto& it : engine.volumePropertiesCommands() ){
+	auto s = engine.volumeProperties( cipherPath,mountPath ).await() ;
 
-		auto a = utility::split( it,' ' ) ;
-		auto b = utility::executableFullPath( a.first() ) ;
-		a.removeFirst() ;
-		auto c = a.join( " " ) ;
+	if( s.isEmpty() ){
 
-		if( !b.isEmpty() ){
-
-			cipherPath = utility::Task::makePath( cipherPath ) ;
-			mountPath  = utility::Task::makePath( mountPath ) ;
-
-			c.replace( "%{cipherFolder}",cipherPath ) ;
-			c.replace( "%{plainFolder}",mountPath ) ;
-
-			auto d = utility::Task::makePath( b ) ;
-
-			auto e = utility::Task::run( d + " " + c ).await() ;
-
-			if( e.success() ){
-
-				return DialogMsg( this ).ShowUIInfo( tr( "INFORMATION" ),true,e.stdOut() ) ;
-			}
-		}
+		this->genericVolumeProperties() ;
+	}else {
+		return DialogMsg( this ).ShowUIInfo( tr( "INFORMATION" ),true,s ) ;
 	}
-
-	this->genericVolumeProperties() ;
 }
 
 void sirikali::genericVolumeProperties()
@@ -1365,6 +1355,7 @@ void sirikali::mount( const volumeInfo& entry,const QString& exe,const QByteArra
 			     m_secrets,
 			     entry,
 			     [ this ](){ this->enableAll() ; },
+			     [ this ](){ this->updateList() ; },
 			     m_autoOpenFolderOnMount,
 			     m_folderOpener,
 			     exe,
@@ -1464,8 +1455,30 @@ void sirikali::updateFavoritesInContextMenu()
 		}
 		int row( const QString& e )
 		{
+			auto x = utility::policyString() ;
+			auto y = "\n" + utility::commentString() ;
+
 			auto a = utility::split( e,'\n' ) ;
 
+			if( e.startsWith( x ) && e.contains( y ) ){
+
+				/*
+				 * we have an fscrypt volume, cipherpath for this volume
+				 * is in a format of "Policy:xys\nComment:abc" and below
+				 * code combines these two into a single entry since
+				 * variable "a" above split it into two.
+				 */
+				if( a.size() > 1 ){
+
+					auto m = a.at( 0 ) + "\n" + a.at( 1 ) ;
+
+					a.removeAt( 0 ) ;
+					a.removeAt( 0 ) ;
+
+					a.insert( 0,m ) ;
+				}
+			}
+
 			if( a.size() == 1 ){
 
 				const auto& m = a.at( 0 ) ;
@@ -1660,6 +1673,11 @@ void sirikali::updateList( const volumeInfo& entry )
 		if( row == -1 ){
 
 			row = tablewidget::addRow( table ) ;
+		}else{
+			if( entry.fileSystem() == "fscrypt" ){
+
+				row = tablewidget::addRow( table ) ;
+			}
 		}
 
 		tablewidget::updateRow( table,entry.mountInfo().minimalList(),row,this->font() ) ;
@@ -1668,16 +1686,16 @@ void sirikali::updateList( const volumeInfo& entry )
 	}
 }
 
-bool sirikali::unMountVolume( const sirikali::mountedEntry& e )
+siritask::taskResult sirikali::unMountVolume( const sirikali::mountedEntry& e )
 {
-	if( siritask::encryptedFolderUnMount( e.cipherPath,e.mountPoint,e.volumeType ) ){
+	auto s = siritask::encryptedFolderUnMount( e.cipherPath,e.mountPoint,e.volumeType,5 ) ;
+
+	if( s.success() && s.engine().backendRequireMountPath() ){
 
 		siritask::deleteMountFolder( e.mountPoint ) ;
-
-		return true ;
-	}else{
-		return false ;
 	}
+
+	return s ;
 }
 
 void sirikali::pbUmount()
@@ -1698,8 +1716,15 @@ void sirikali::pbUmount()
 
 		utility::waitForOneSecond() ;
 
-		if( !this->unMountVolume( { a,b,c } ) ){
+		auto s = this->unMountVolume( { a,b,c } ) ;
 
+		if( s.success() ){
+
+			if( s.backendDoesNotAutoRefresh() ){
+
+				this->updateList() ;
+			}
+		}else{
 			DialogMsg( this ).ShowUIOK( tr( "ERROR" ),tr( "Failed To Unmount %1 Volume" ).arg( type ) ) ;
 
 			this->enableAll() ;
@@ -1751,7 +1776,7 @@ void sirikali::unMountAll()
 
 	this->processMountedVolumes( [ this ]( const mountedEntry& e ){
 
-		if( this->unMountVolume( e ) ){
+		if( this->unMountVolume( e ).success() ){
 
 			tablewidget::deleteRow( m_ui->tableWidget,e.mountPoint,1 ) ;
 
@@ -1771,6 +1796,8 @@ void sirikali::unMountAll()
 		}
 	}
 
+	this->updateList() ;
+
 	this->enableAll() ;
 
 	m_mountInfo.announceEvents( true ) ;
@@ -1786,10 +1813,8 @@ void sirikali::unMountAllAndQuit()
 	}
 }
 
-void sirikali::pbUpdate()
+void sirikali::updateList()
 {
-	this->disableAll() ;
-
 	if( utility::platformIsWindows() ){
 
 		this->updateVolumeList( mountinfo::unlockedVolumes().get() ) ;
@@ -1800,6 +1825,13 @@ void sirikali::pbUpdate()
 	this->updateFavoritesInContextMenu() ;
 }
 
+void sirikali::pbUpdate()
+{
+	this->disableAll() ;
+
+	this->updateList() ;
+}
+
 void sirikali::updateVolumeList( const std::vector< volumeInfo >& r )
 {
 	tablewidget::clearTable( m_ui->tableWidget ) ;
