@@ -368,6 +368,11 @@ void utility::logCommandOutPut( const QString& e )
 
 void utility::logCommandOutPut( const ::Task::process::result& m,const QString& exe )
 {
+	if( exe.contains( "fscrypt status" ) ){
+
+		return ;
+	}
+
 	auto _trim = []( QString e ){
 
 		while( true ){
@@ -1120,7 +1125,8 @@ QString utility::readPassword( bool addNewLine )
 
 const QProcessEnvironment& utility::systemEnvironment()
 {
-	return utility::globalEnvironment().instance().get() ;
+	static QProcessEnvironment env = QProcessEnvironment::systemEnvironment() ;
+	return env ;
 }
 
 QString utility::configFilePath( QWidget * s,const QString& e )
@@ -1387,37 +1393,6 @@ QString utility::wrap_su( const QString& s )
 	}
 }
 
-utility::globalEnvironment& utility::globalEnvironment::instance()
-{
-	static utility::globalEnvironment m ;
-	return m ;
-}
-
-const QProcessEnvironment& utility::globalEnvironment::get() const
-{
-	return m_environment ;
-}
-
-void utility::globalEnvironment::remove( const QString& e )
-{
-	m_environment.remove( e ) ;
-}
-
-void utility::globalEnvironment::insert( const QString& key,const QString& value )
-{
-	m_environment.insert( key,value ) ;
-}
-
-utility::globalEnvironment::globalEnvironment() :
-	m_environment( QProcessEnvironment::systemEnvironment() )
-{
-	auto m = utility::executableSearchPaths( m_environment.value( "PATH" ) ) ;
-
-	m_environment.insert( "PATH",m ) ;
-
-	m_environment.insert( "LANG","C" ) ;
-}
-
 void utility::setGUIThread()
 {
 	_main_gui_thread = QThread::currentThread() ;
@@ -1500,3 +1475,13 @@ utility::result< QByteArray > utility::yubiKey( const QString& challenge )
 
 	return {} ;
 }
+
+QString utility::policyString()
+{
+	return QObject::tr( "Policy:" ) ;
+}
+
+QString utility::commentString()
+{
+	return QObject::tr( "Comment:" ) ;
+}
