@@ -144,18 +144,6 @@ namespace utility
 		bool m_valid = false ;
 		T m_value ;
 	} ;
-
-	class globalEnvironment
-	{
-	public:
-		static globalEnvironment& instance() ;
-		const QProcessEnvironment& get() const ;
-		void insert( const QString&,const QString& ) ;
-		void remove( const QString& ) ;
-		globalEnvironment() ;
-	private:
-		QProcessEnvironment m_environment ;
-	} ;
 }
 
 namespace utility
@@ -374,6 +362,9 @@ namespace utility
 
 	QString configFilePath( QWidget *,const QString& ) ;
 
+	QString policyString() ;
+	QString commentString() ;
+
 	QStringList split( const QString&,char = '\n' ) ;
 	QStringList executableSearchPaths( void ) ;
 	QString executableSearchPaths( const QString& ) ;
